@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000006';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000007';
 use Moose;
 use namespace::autoclean;
 
@@ -77,8 +77,10 @@ sub configure {
     my $self = shift;
 
     my $readme     = 'README.md';
-    my @from_build = qw(INSTALL LICENSE META.json);
-    my @copy       = ( 'cpanfile', 'Makefile.PL', $readme );
+    my @from_build = qw(INSTALL META.json);
+    my @copy       = ( 'cpanfile', 'LICENSE', 'Makefile.PL', $readme );
+
+    my @allow_dirty = ( 'dist.ini', 'Changes', @copy, @from_build );
 
     # Must come before Git::Commit
     $self->add_plugins('NextRelease');
@@ -94,12 +96,12 @@ sub configure {
         [ 'GithubMeta' => { issues => 1 } ],
         'ExtraTests',
         [ 'Git::GatherDir' => { exclude_filename => \@copy } ],
+        [ 'Git::Check'     => { allow_dirty      => \@allow_dirty } ],
         [
-            'Git::Check' => {
-                allow_dirty => [ 'dist.ini', 'Changes', @copy, @from_build ]
-            }
+            'Git::Commit' => 'commit generated files' => {
+                allow_dirty => \@allow_dirty,
+            },
         ],
-        'Git::Commit',
         'Git::Contributors',
         'Git::Tag',
         'Git::Push',
@@ -177,7 +179,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000006
+version 0.000007
 
 =head2 configure
 
